@@ -510,8 +510,7 @@ class ReportGenerator:
         if not self._chart_data or not getattr(self._chart_data, "aspects", None):
             return ""
 
-        aspects_model = self._chart_data.aspects
-        aspects_list = list(getattr(aspects_model, "aspects", []))
+        aspects_list = list(self._chart_data.aspects)
 
         if not aspects_list:
             return "No aspects data available."
@@ -728,8 +727,7 @@ if __name__ == "__main__":
         natal_subject.iso_formatted_local_datetime,
         "Solar",
     )
-
-    # Composite chart subject
+    # Derive a composite subject representing the pair's midpoint configuration
     composite_subject = CompositeSubjectFactory(
         natal_subject,
         partner_subject,
