@@ -22,7 +22,7 @@ EXPECTED_ALL_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 323.08350724138,
         "aspect": "trine",
-        "orbit": -5.423422573446004,
+        "orbit": 5.423422573446004,
         "aspect_degrees": 120,
         "diff": 245.423422573446,
         "p1": 0,
@@ -67,7 +67,7 @@ EXPECTED_ALL_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 320.69667227209675,
         "aspect": "trine",
-        "orbit": -3.0365876041627473,
+        "orbit": 3.0365876041627473,
         "aspect_degrees": 120,
         "diff": 243.03658760416275,
         "p1": 0,
@@ -142,7 +142,7 @@ EXPECTED_ALL_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 223.4234728645222,
         "aspect": "sextile",
-        "orbit": -4.683287615498585,
+        "orbit": 4.683287615498585,
         "aspect_degrees": 60,
         "diff": 55.316712384501415,
         "p1": 1,
@@ -157,7 +157,7 @@ EXPECTED_ALL_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 159.6256451582548,
         "aspect": "trine",
-        "orbit": -0.885459909231173,
+        "orbit": 0.885459909231173,
         "aspect_degrees": 120,
         "diff": 119.11454009076883,
         "p1": 1,
@@ -232,7 +232,7 @@ EXPECTED_ALL_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 110.6397110305168,
         "aspect": "sextile",
-        "orbit": -4.362439751621366,
+        "orbit": 4.362439751621366,
         "aspect_degrees": 60,
         "diff": 55.63756024837862,
         "p1": 2,
@@ -262,7 +262,7 @@ EXPECTED_ALL_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 140.69667227209675,
         "aspect": "square",
-        "orbit": -4.305478510041439,
+        "orbit": 4.305478510041439,
         "aspect_degrees": 90,
         "diff": 85.69452148995856,
         "p1": 2,
@@ -322,7 +322,7 @@ EXPECTED_ALL_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 110.6397110305168,
         "aspect": "sextile",
-        "orbit": -4.9645293282158605,
+        "orbit": 4.9645293282158605,
         "aspect_degrees": 60,
         "diff": 55.03547067178416,
         "p1": 3,
@@ -352,7 +352,7 @@ EXPECTED_ALL_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 140.69667227209675,
         "aspect": "square",
-        "orbit": -4.9075680866359335,
+        "orbit": 4.9075680866359335,
         "aspect_degrees": 90,
         "diff": 85.0924319133641,
         "p1": 3,
@@ -397,7 +397,7 @@ EXPECTED_ALL_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 323.08350724138,
         "aspect": "opposition",
-        "orbit": -9.928369264006875,
+        "orbit": 9.928369264006875,
         "aspect_degrees": 180,
         "diff": 170.07163073599312,
         "p1": 4,
@@ -457,7 +457,7 @@ EXPECTED_ALL_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 66.58774889387882,
         "aspect": "square",
-        "orbit": -3.5758723884919448,
+        "orbit": 3.5758723884919448,
         "aspect_degrees": 90,
         "diff": 86.42412761150806,
         "p1": 4,
@@ -517,7 +517,7 @@ EXPECTED_ALL_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 151.56664806991213,
         "aspect": "opposition",
-        "orbit": -8.483140828532129,
+        "orbit": 8.483140828532129,
         "aspect_degrees": 180,
         "diff": 171.51685917146787,
         "p1": 6,
@@ -547,7 +547,7 @@ EXPECTED_ALL_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 140.69667227209675,
         "aspect": "opposition",
-        "orbit": -2.3868349692832567,
+        "orbit": 2.3868349692832567,
         "aspect_degrees": 180,
         "diff": 182.38683496928326,
         "p1": 6,
@@ -562,7 +562,7 @@ EXPECTED_ALL_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 223.4234728645222,
         "aspect": "quintile",
-        "orbit": -0.14317520538992312,
+        "orbit": 0.14317520538992312,
         "aspect_degrees": 72,
         "diff": 71.85682479461008,
         "p1": 7,
@@ -652,7 +652,7 @@ EXPECTED_ALL_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 110.6397110305168,
         "aspect": "trine",
-        "orbit": -7.216238165994596,
+        "orbit": 7.216238165994596,
         "aspect_degrees": 120,
         "diff": 112.7837618340054,
         "p1": 8,
@@ -697,7 +697,7 @@ EXPECTED_ALL_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 344.8739690319904,
         "aspect": "opposition",
-        "orbit": -5.248323873735586,
+        "orbit": 5.248323873735586,
         "aspect_degrees": 180,
         "diff": 185.2483238737356,
         "p1": 9,
@@ -712,7 +712,7 @@ EXPECTED_ALL_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 246.58774889387882,
         "aspect": "square",
-        "orbit": -3.037896264375945,
+        "orbit": 3.037896264375945,
         "aspect_degrees": 90,
         "diff": 86.96210373562403,
         "p1": 9,
@@ -742,7 +742,7 @@ EXPECTED_ALL_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 215.57257521008046,
         "aspect": "sextile",
-        "orbit": -4.053069948174311,
+        "orbit": 4.053069948174311,
         "aspect_degrees": 60,
         "diff": 55.94693005182566,
         "p1": 9,
@@ -772,7 +772,7 @@ EXPECTED_ALL_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 290.6397110305168,
         "aspect": "sextile",
-        "orbit": -5.765741998526437,
+        "orbit": 5.765741998526437,
         "aspect_degrees": 60,
         "diff": 54.23425800147356,
         "p1": 12,
@@ -805,7 +805,7 @@ EXPECTED_RELEVANT_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 323.08350724138,
         "aspect": "trine",
-        "orbit": -5.423422573446004,
+        "orbit": 5.423422573446004,
         "aspect_degrees": 120,
         "diff": 245.423422573446,
         "p1": 0,
@@ -850,7 +850,7 @@ EXPECTED_RELEVANT_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 320.69667227209675,
         "aspect": "trine",
-        "orbit": -3.0365876041627473,
+        "orbit": 3.0365876041627473,
         "aspect_degrees": 120,
         "diff": 243.03658760416275,
         "p1": 0,
@@ -925,7 +925,7 @@ EXPECTED_RELEVANT_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 223.4234728645222,
         "aspect": "sextile",
-        "orbit": -4.683287615498585,
+        "orbit": 4.683287615498585,
         "aspect_degrees": 60,
         "diff": 55.316712384501415,
         "p1": 1,
@@ -940,7 +940,7 @@ EXPECTED_RELEVANT_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 159.6256451582548,
         "aspect": "trine",
-        "orbit": -0.885459909231173,
+        "orbit": 0.885459909231173,
         "aspect_degrees": 120,
         "diff": 119.11454009076883,
         "p1": 1,
@@ -1015,7 +1015,7 @@ EXPECTED_RELEVANT_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 110.6397110305168,
         "aspect": "sextile",
-        "orbit": -4.362439751621366,
+        "orbit": 4.362439751621366,
         "aspect_degrees": 60,
         "diff": 55.63756024837862,
         "p1": 2,
@@ -1045,7 +1045,7 @@ EXPECTED_RELEVANT_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 140.69667227209675,
         "aspect": "square",
-        "orbit": -4.305478510041439,
+        "orbit": 4.305478510041439,
         "aspect_degrees": 90,
         "diff": 85.69452148995856,
         "p1": 2,
@@ -1105,7 +1105,7 @@ EXPECTED_RELEVANT_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 110.6397110305168,
         "aspect": "sextile",
-        "orbit": -4.9645293282158605,
+        "orbit": 4.9645293282158605,
         "aspect_degrees": 60,
         "diff": 55.03547067178416,
         "p1": 3,
@@ -1135,7 +1135,7 @@ EXPECTED_RELEVANT_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 140.69667227209675,
         "aspect": "square",
-        "orbit": -4.9075680866359335,
+        "orbit": 4.9075680866359335,
         "aspect_degrees": 90,
         "diff": 85.0924319133641,
         "p1": 3,
@@ -1180,7 +1180,7 @@ EXPECTED_RELEVANT_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 323.08350724138,
         "aspect": "opposition",
-        "orbit": -9.928369264006875,
+        "orbit": 9.928369264006875,
         "aspect_degrees": 180,
         "diff": 170.07163073599312,
         "p1": 4,
@@ -1240,7 +1240,7 @@ EXPECTED_RELEVANT_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 66.58774889387882,
         "aspect": "square",
-        "orbit": -3.5758723884919448,
+        "orbit": 3.5758723884919448,
         "aspect_degrees": 90,
         "diff": 86.42412761150806,
         "p1": 4,
@@ -1300,7 +1300,7 @@ EXPECTED_RELEVANT_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 151.56664806991213,
         "aspect": "opposition",
-        "orbit": -8.483140828532129,
+        "orbit": 8.483140828532129,
         "aspect_degrees": 180,
         "diff": 171.51685917146787,
         "p1": 6,
@@ -1330,7 +1330,7 @@ EXPECTED_RELEVANT_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 140.69667227209675,
         "aspect": "opposition",
-        "orbit": -2.3868349692832567,
+        "orbit": 2.3868349692832567,
         "aspect_degrees": 180,
         "diff": 182.38683496928326,
         "p1": 6,
@@ -1345,7 +1345,7 @@ EXPECTED_RELEVANT_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 223.4234728645222,
         "aspect": "quintile",
-        "orbit": -0.14317520538992312,
+        "orbit": 0.14317520538992312,
         "aspect_degrees": 72,
         "diff": 71.85682479461008,
         "p1": 7,
@@ -1435,7 +1435,7 @@ EXPECTED_RELEVANT_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 110.6397110305168,
         "aspect": "trine",
-        "orbit": -7.216238165994596,
+        "orbit": 7.216238165994596,
         "aspect_degrees": 120,
         "diff": 112.7837618340054,
         "p1": 8,
@@ -1480,7 +1480,7 @@ EXPECTED_RELEVANT_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 344.8739690319904,
         "aspect": "opposition",
-        "orbit": -5.248323873735586,
+        "orbit": 5.248323873735586,
         "aspect_degrees": 180,
         "diff": 185.2483238737356,
         "p1": 9,
@@ -1495,7 +1495,7 @@ EXPECTED_RELEVANT_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 246.58774889387882,
         "aspect": "square",
-        "orbit": -3.037896264375945,
+        "orbit": 3.037896264375945,
         "aspect_degrees": 90,
         "diff": 86.96210373562403,
         "p1": 9,
@@ -1525,7 +1525,7 @@ EXPECTED_RELEVANT_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 215.57257521008046,
         "aspect": "sextile",
-        "orbit": -4.053069948174311,
+        "orbit": 4.053069948174311,
         "aspect_degrees": 60,
         "diff": 55.94693005182566,
         "p1": 9,
@@ -1555,7 +1555,7 @@ EXPECTED_RELEVANT_ASPECTS = [
         "p2_owner": "Johnny Depp",
         "p2_abs_pos": 290.6397110305168,
         "aspect": "sextile",
-        "orbit": -5.765741998526437,
+        "orbit": 5.765741998526437,
         "aspect_degrees": 60,
         "diff": 54.23425800147356,
         "p1": 12,
