@@ -3,6 +3,8 @@ from kerykeion.schemas import AstrologicalPoint
 from typing import get_args
 from pytest import approx
 
+from tests.data.expected_astrological_subjects import EXPECTED_TROPICAL_SUBJECT
+
 
 class TestAstrologicalSubject:
     def setup_class(self):
@@ -12,392 +14,8 @@ class TestAstrologicalSubject:
             "Johnny Depp", 1963, 6, 9, 0, 0, "Owensboro", "US",
             suppress_geonames_warning=True, active_points=all_points
         )
-        self.expected_output = {
-            "name": "Johnny Depp",
-            "year": 1963,
-            "month": 6,
-            "day": 9,
-            "hour": 0,
-            "minute": 0,
-            "city": "Owensboro",
-            "nation": "US",
-            "lng": -87.11333,
-            "lat": 37.77422,
-            "tz_str": "America/Chicago",
-            "zodiac_type": "Tropic",
-            "julian_day": 2438189.7083333335,
-            # Deprecated -->
-            "local_time": 0.0,
-            "utc_time": 5.0,
-            # <-- Deprecated
+        self.expected_output = EXPECTED_TROPICAL_SUBJECT
 
-            "ascendant": {
-                "name": "Ascendant",
-                "quality": "Fixed",
-                "element": "Air",
-                "sign": "Aqu",
-                "sign_num": 10,
-                "position": 20.696672272096748,
-                "abs_pos": 320.69667227209675,
-                "emoji": "♒️",
-                "point_type": "AstrologicalPoint",
-                "house": "First_House",
-                "retrograde": False,
-            },
-            "descendant": {
-                "name": "Descendant",
-                "quality": "Fixed",
-                "element": "Fire",
-                "sign": "Leo",
-                "sign_num": 4,
-                "position": 20.696672272096748,
-                "abs_pos": 140.69667227209675,
-                "emoji": "♌️",
-                "point_type": "AstrologicalPoint",
-                "house": "Seventh_House",
-                "retrograde": False,
-            },
-            "medium_coeli": {
-                "name": "Medium_Coeli",
-                "quality": "Mutable",
-                "element": "Fire",
-                "sign": "Sag",
-                "sign_num": 8,
-                "position": 6.58774889387882,
-                "abs_pos": 246.58774889387882,
-                "emoji": "♐️",
-                "point_type": "AstrologicalPoint",
-                "house": "Tenth_House",
-                "retrograde": False,
-            },
-            "imum_coeli": {
-                "name": "Imum_Coeli",
-                "quality": "Mutable",
-                "element": "Air",
-                "sign": "Gem",
-                "sign_num": 2,
-                "position": 6.58774889387882,
-                "abs_pos": 66.58774889387882,
-                "emoji": "♊️",
-                "point_type": "AstrologicalPoint",
-                "house": "Fourth_House",
-                "retrograde": False,
-            },
-            "sun": {
-                "name": "Sun",
-                "quality": "Mutable",
-                "element": "Air",
-                "sign": "Gem",
-                "sign_num": 2,
-                "position": 17.659700723619764,
-                "abs_pos": 77.65970072361976,
-                "emoji": "♊️",
-                "point_type": "AstrologicalPoint",
-                "house": "Fourth_House",
-                "retrograde": False,
-                "speed": 0.955992,
-                "declination": 22.8702,
-            },
-            "moon": {
-                "name": "Moon",
-                "quality": "Cardinal",
-                "element": "Earth",
-                "sign": "Cap",
-                "sign_num": 9,
-                "position": 8.735173210893663,
-                "abs_pos": 278.73517321089366,
-                "emoji": "♑️",
-                "point_type": "AstrologicalPoint",
-                "house": "Eleventh_House",
-                "retrograde": False,
-                "speed": 12.479586,
-                "declination": -22.0821,
-            },
-            "mercury": {
-                "name": "Mercury",
-                "quality": "Fixed",
-                "element": "Earth",
-                "sign": "Tau",
-                "sign_num": 1,
-                "position": 25.00187700457719,
-                "abs_pos": 55.00187700457719,
-                "emoji": "♉️",
-                "point_type": "AstrologicalPoint",
-                "house": "Third_House",
-                "retrograde": False,
-                "speed": 0.681694,
-                "declination": 15.2697,
-            },
-            "venus": {
-                "name": "Venus",
-                "quality": "Fixed",
-                "element": "Earth",
-                "sign": "Tau",
-                "sign_num": 1,
-                "position": 25.603753240224542,
-                "abs_pos": 55.60375324022454,
-                "emoji": "♉️",
-                "point_type": "AstrologicalPoint",
-                "house": "Third_House",
-                "retrograde": False,
-                "speed": 1.212889,
-                "declination": 17.9459,
-            },
-            "mars": {
-                "name": "Mars",
-                "quality": "Mutable",
-                "element": "Earth",
-                "sign": "Vir",
-                "sign_num": 5,
-                "position": 3.0116698475575276,
-                "abs_pos": 153.01166984755753,
-                "emoji": "♍️",
-                "point_type": "AstrologicalPoint",
-                "house": "Seventh_House",
-                "retrograde": False,
-                "speed": 0.514563,
-                "declination": 11.5452,
-            },
-            "jupiter": {
-                "name": "Jupiter",
-                "quality": "Cardinal",
-                "element": "Fire",
-                "sign": "Ari",
-                "sign_num": 0,
-                "position": 13.910952211401664,
-                "abs_pos": 13.910952211401664,
-                "emoji": "♈️",
-                "point_type": "AstrologicalPoint",
-                "house": "Second_House",
-                "retrograde": False,
-                "speed": 0.165966,
-                "declination": 4.3749,
-            },
-            "saturn": {
-                "name": "Saturn",
-                "quality": "Fixed",
-                "element": "Air",
-                "sign": "Aqu",
-                "sign_num": 10,
-                "position": 23.083510999945474,
-                "abs_pos": 323.0835109999455,
-                "emoji": "♒️",
-                "point_type": "AstrologicalPoint",
-                "house": "First_House",
-                "retrograde": True,
-                "speed": -0.009360,
-                "declination": -14.8430,
-            },
-            "uranus": {
-                "name": "Uranus",
-                "quality": "Mutable",
-                "element": "Earth",
-                "sign": "Vir",
-                "sign_num": 5,
-                "position": 1.5666373257095927,
-                "abs_pos": 151.5666373257096,
-                "emoji": "♍️",
-                "point_type": "AstrologicalPoint",
-                "house": "Seventh_House",
-                "retrograde": False,
-                "speed": 0.026753,
-                "declination": 11.6218,
-            },
-            "neptune": {
-                "name": "Neptune",
-                "quality": "Fixed",
-                "element": "Water",
-                "sign": "Sco",
-                "sign_num": 7,
-                "position": 13.423481419291079,
-                "abs_pos": 223.42348141929108,
-                "emoji": "♏️",
-                "point_type": "AstrologicalPoint",
-                "house": "Ninth_House",
-                "retrograde": True,
-                "speed": -0.021301,
-                "declination": -14.1326,
-            },
-            "pluto": {
-                "name": "Pluto",
-                "quality": "Mutable",
-                "element": "Earth",
-                "sign": "Vir",
-                "sign_num": 5,
-                "position": 9.625641361989636,
-                "abs_pos": 159.62564136198964,
-                "emoji": "♍️",
-                "point_type": "AstrologicalPoint",
-                "house": "Seventh_House",
-                "retrograde": False,
-                "speed": 0.009451,
-                "declination": 20.4574,
-            },
-            "first_house": {
-                "name": "First_House",
-                "quality": "Fixed",
-                "element": "Air",
-                "sign": "Aqu",
-                "sign_num": 10,
-                "position": 20.696672272096748,
-                "abs_pos": 320.69667227209675,
-                "emoji": "♒️",
-                "point_type": "House",
-            },
-            "second_house": {
-                "name": "Second_House",
-                "quality": "Cardinal",
-                "element": "Fire",
-                "sign": "Ari",
-                "sign_num": 0,
-                "position": 6.643247095515116,
-                "abs_pos": 6.643247095515116,
-                "emoji": "♈️",
-                "point_type": "House",
-            },
-            "third_house": {
-                "name": "Third_House",
-                "quality": "Fixed",
-                "element": "Earth",
-                "sign": "Tau",
-                "sign_num": 1,
-                "position": 11.215413957987053,
-                "abs_pos": 41.21541395798705,
-                "emoji": "♉️",
-                "point_type": "House",
-            },
-            "fourth_house": {
-                "name": "Fourth_House",
-                "quality": "Mutable",
-                "element": "Air",
-                "sign": "Gem",
-                "sign_num": 2,
-                "position": 6.587748893878825,
-                "abs_pos": 66.58774889387882,
-                "emoji": "♊️",
-                "point_type": "House",
-            },
-            "fifth_house": {
-                "name": "Fifth_House",
-                "quality": "Mutable",
-                "element": "Air",
-                "sign": "Gem",
-                "sign_num": 2,
-                "position": 28.34219396577589,
-                "abs_pos": 88.34219396577589,
-                "emoji": "♊️",
-                "point_type": "House",
-            },
-            "sixth_house": {
-                "name": "Sixth_House",
-                "quality": "Cardinal",
-                "element": "Water",
-                "sign": "Can",
-                "sign_num": 3,
-                "position": 20.99073151066341,
-                "abs_pos": 110.99073151066341,
-                "emoji": "♋️",
-                "point_type": "House",
-            },
-            "seventh_house": {
-                "name": "Seventh_House",
-                "quality": "Fixed",
-                "element": "Fire",
-                "sign": "Leo",
-                "sign_num": 4,
-                "position": 20.696672272096748,
-                "abs_pos": 140.69667227209675,
-                "emoji": "♌️",
-                "point_type": "House",
-            },
-            "eighth_house": {
-                "name": "Eighth_House",
-                "quality": "Cardinal",
-                "element": "Air",
-                "sign": "Lib",
-                "sign_num": 6,
-                "position": 6.6432470955151075,
-                "abs_pos": 186.6432470955151,
-                "emoji": "♎️",
-                "point_type": "House",
-            },
-            "ninth_house": {
-                "name": "Ninth_House",
-                "quality": "Fixed",
-                "element": "Water",
-                "sign": "Sco",
-                "sign_num": 7,
-                "position": 11.215413957987039,
-                "abs_pos": 221.21541395798704,
-                "emoji": "♏️",
-                "point_type": "House",
-            },
-            "tenth_house": {
-                "name": "Tenth_House",
-                "quality": "Mutable",
-                "element": "Fire",
-                "sign": "Sag",
-                "sign_num": 8,
-                "position": 6.587748893878825,
-                "abs_pos": 246.58774889387882,
-                "emoji": "♐️",
-                "point_type": "House",
-            },
-            "eleventh_house": {
-                "name": "Eleventh_House",
-                "quality": "Mutable",
-                "element": "Fire",
-                "sign": "Sag",
-                "sign_num": 8,
-                "position": 28.34219396577589,
-                "abs_pos": 268.3421939657759,
-                "emoji": "♐️",
-                "point_type": "House",
-            },
-            "twelfth_house": {
-                "name": "Twelfth_House",
-                "quality": "Cardinal",
-                "element": "Earth",
-                "sign": "Cap",
-                "sign_num": 9,
-                "position": 20.99073151066341,
-                "abs_pos": 290.9907315106634,
-                "emoji": "♑️",
-                "point_type": "House",
-            },
-            "true_north_lunar_node": {
-                "name": "True_North_Lunar_Node",
-                "quality": "Cardinal",
-                "element": "Water",
-                "sign": "Can",
-                "sign_num": 3,
-                "position": 20.63971940408193,
-                "abs_pos": 110.63971940408193,
-                "emoji": "♋️",
-                "point_type": "AstrologicalPoint",
-                "house": "Fifth_House",
-                "retrograde": True,
-            },
-            "true_south_lunar_node": {
-                "name": "True_South_Lunar_Node",
-                "quality": "Cardinal",
-                "element": "Earth",
-                "sign": "Cap",
-                "sign_num": 9,
-                "position": 20.63971940408193,
-                "abs_pos": 290.63971940408193,
-                "emoji": "♑️",
-                "point_type": "AstrologicalPoint",
-                "house": "Eleventh_House",
-                "retrograde": True,
-            },
-            "lunar_phase": {
-                "degrees_between_s_m": 201.07547248727332,
-                "moon_phase": 16,
-                "moon_emoji": "🌖",
-                "moon_phase_name": "Waning Gibbous"
-            },
-        }
 
     def test_basic_input_data(self):
         assert self.subject.name == self.expected_output["name"]
@@ -1025,7 +643,7 @@ class TestChartConfiguration:
 
         with pytest.raises(KerykeionException):
             ChartConfiguration(
-                zodiac_type="Tropic",
+                zodiac_type="Tropical",
                 sidereal_mode="LAHIRI"
             )
 
@@ -1038,6 +656,9 @@ class TestChartConfiguration:
         with pytest.raises(KerykeionException):
             ChartConfiguration(zodiac_type="InvalidType")
 
+        with pytest.raises(KerykeionException):
+            ChartConfiguration(zodiac_type="Tropics")
+
     def test_invalid_house_system_raises_error(self):
         """Test that invalid house system raises error."""
         from kerykeion.astrological_subject_factory import ChartConfiguration
@@ -1535,7 +1156,7 @@ class TestComprehensiveCoverage:
     def test_all_perspectives_and_zodiacs(self):
         """Test all combinations to ensure full coverage."""
         perspectives = ["Apparent Geocentric", "True Geocentric", "Heliocentric", "Topocentric"]
-        zodiacs = ["Tropic", "Sidereal"]
+        zodiacs = ["Tropical", "Sidereal"]
 
         for perspective in perspectives:
             for zodiac in zodiacs:
@@ -1563,6 +1184,7 @@ class TestComprehensiveCoverage:
 
                 subject = AstrologicalSubjectFactory.from_birth_data(**kwargs)
                 assert subject.name == f"{perspective}-{zodiac}"
+                assert subject.zodiac_type == zodiac
 
 
 class TestMockErrorConditions:
@@ -1907,13 +1529,3 @@ class TestAllDwarfPlanetsAndFixedStars:
         assert hasattr(subject.spica, 'abs_pos')
         assert not subject.spica.retrograde
             # Vertex and Anti_Vertex removed from active_points due to error
-
-
-if __name__ == "__main__":
-    import pytest
-    import logging
-
-    # Set the log level to CRITICAL
-    logging.basicConfig(level=logging.CRITICAL)
-
-    pytest.main(["-vv", "--log-level=CRITICAL", "--log-cli-level=CRITICAL", __file__])
