@@ -1,6 +1,8 @@
 from kerykeion import AstrologicalSubjectFactory
 from pytest import approx
 
+from tests.data.expected_astrological_subjects import EXPECTED_JYOTISH_SUBJECT
+
 
 class TestAstrologicalSubjectJyotish:
     def setup_class(self):
@@ -9,398 +11,8 @@ class TestAstrologicalSubjectJyotish:
         self.subject = AstrologicalSubjectFactory.from_birth_data("Johnny Depp", 1963, 6, 9, 0, 0, "Owensboro", "US", \
             zodiac_type="Sidereal", sidereal_mode="LAHIRI", houses_system_identifier="W", suppress_geonames_warning=True)
 
-        self.expected_output = {
-            "name": "Johnny Depp",
-            "year": 1963,
-            "month": 6,
-            "day": 9,
-            "hour": 0,
-            "minute": 0,
-            "city": "Owensboro",
-            "nation": "US",
-            "lng": -87.11333,
-            "lat": 37.77422,
-            "tz_str": "America/Chicago",
-            "zodiac_type": "Sidereal",
-            "julian_day": 2438189.7083333335,
-            # Deprecated -->
-            "local_time": 0.0,
-            "utc_time": 5.0,
-            # <-- Deprecated
+        self.expected_output = EXPECTED_JYOTISH_SUBJECT
 
-            "ascendant": {
-                "name": "Ascendant",
-                "quality": "Cardinal",
-                "element": "Earth",
-                "sign": "Cap",
-                "sign_num": 9,
-                "position": 27.35490680258141,
-                "abs_pos": 297.3549068025814,
-                "emoji": "♑️",
-                "point_type": "AstrologicalPoint",
-                "house": "First_House",
-                "retrograde": False,
-            },
-            "descendant": {
-                "name": "Descendant",
-                "quality": "Cardinal",
-                "element": "Water",
-                "sign": "Can",
-                "sign_num": 3,
-                "position": 27.35490680258141,
-                "abs_pos": 117.35490680258141,
-                "emoji": "♋️",
-                "point_type": "AstrologicalPoint",
-                "house": "Seventh_House",
-                "retrograde": False,
-            },
-            "medium_coeli": {
-                "name": "Medium_Coeli",
-                "quality": "Fixed",
-                "element": "Water",
-                "sign": "Sco",
-                "sign_num": 7,
-                "position": 13.245983424363487,
-                "abs_pos": 223.2459834243635,
-                "emoji": "♏️",
-                "point_type": "AstrologicalPoint",
-                "house": "Eleventh_House",
-                "retrograde": False,
-            },
-            "imum_coeli": {
-                "name": "Imum_Coeli",
-                "quality": "Fixed",
-                "element": "Earth",
-                "sign": "Tau",
-                "sign_num": 1,
-                "position": 13.245983424363487,
-                "abs_pos": 43.24598342436349,
-                "emoji": "♉️",
-                "point_type": "AstrologicalPoint",
-                "house": "Fifth_House",
-                "retrograde": False,
-            },
-            "sun": {
-                "name": "Sun",
-                "quality": "Fixed",
-                "element": "Earth",
-                "sign": "Tau",
-                "sign_num": 1,
-                "position": 24.31793528253837,
-                "abs_pos": 54.31793528253837,
-                "emoji": "♉️",
-                "point_type": "AstrologicalPoint",
-                "house": "Fifth_House",
-                "retrograde": False,
-            },
-            "moon": {
-                "name": "Moon",
-                "quality": "Mutable",
-                "element": "Fire",
-                "sign": "Sag",
-                "sign_num": 8,
-                "position": 15.39340776981174,
-                "abs_pos": 255.39340776981174,
-                "emoji": "♐️",
-                "point_type": "AstrologicalPoint",
-                "house": "Twelfth_House",
-                "retrograde": False,
-            },
-            "mercury": {
-                "name": "Mercury",
-                "quality": "Fixed",
-                "element": "Earth",
-                "sign": "Tau",
-                "sign_num": 1,
-                "position": 1.66011156351147,
-                "abs_pos": 31.66011156351147,
-                "emoji": "♉️",
-                "point_type": "AstrologicalPoint",
-                "house": "Fifth_House",
-                "retrograde": False,
-            },
-            "venus": {
-                "name": "Venus",
-                "quality": "Fixed",
-                "element": "Earth",
-                "sign": "Tau",
-                "sign_num": 1,
-                "position": 2.261987799142716,
-                "abs_pos": 32.261987799142716,
-                "emoji": "♉️",
-                "point_type": "AstrologicalPoint",
-                "house": "Fifth_House",
-                "retrograde": False,
-            },
-            "mars": {
-                "name": "Mars",
-                "quality": "Fixed",
-                "element": "Fire",
-                "sign": "Leo",
-                "sign_num": 4,
-                "position": 9.6699044063961,
-                "abs_pos": 129.6699044063961,
-                "emoji": "♌️",
-                "point_type": "AstrologicalPoint",
-                "house": "Eighth_House",
-                "retrograde": False,
-            },
-            "jupiter": {
-                "name": "Jupiter",
-                "quality": "Mutable",
-                "element": "Water",
-                "sign": "Pis",
-                "sign_num": 11,
-                "position": 20.5691867703156,
-                "abs_pos": 350.5691867703156,
-                "emoji": "♓️",
-                "point_type": "AstrologicalPoint",
-                "house": "Third_House",
-                "retrograde": False,
-            },
-            "saturn": {
-                "name": "Saturn",
-                "quality": "Cardinal",
-                "element": "Earth",
-                "sign": "Cap",
-                "sign_num": 9,
-                "position": 29.74174555889493,
-                "abs_pos": 299.74174555889493,
-                "emoji": "♑️",
-                "point_type": "AstrologicalPoint",
-                "house": "First_House",
-                "retrograde": True,
-            },
-            "uranus": {
-                "name": "Uranus",
-                "quality": "Fixed",
-                "element": "Fire",
-                "sign": "Leo",
-                "sign_num": 4,
-                "position": 8.2248718846302,
-                "abs_pos": 128.2248718846302,
-                "emoji": "♌️",
-                "point_type": "AstrologicalPoint",
-                "house": "Eighth_House",
-                "retrograde": False,
-            },
-            "neptune": {
-                "name": "Neptune",
-                "quality": "Cardinal",
-                "element": "Air",
-                "sign": "Lib",
-                "sign_num": 6,
-                "position": 20.08171597826217,
-                "abs_pos": 200.08171597826217,
-                "emoji": "♎️",
-                "point_type": "AstrologicalPoint",
-                "house": "Tenth_House",
-                "retrograde": True,
-            },
-            "pluto": {
-                "name": "Pluto",
-                "quality": "Fixed",
-                "element": "Fire",
-                "sign": "Leo",
-                "sign_num": 4,
-                "position": 16.283875921047326,
-                "abs_pos": 136.28387592104733,
-                "emoji": "♌️",
-                "point_type": "AstrologicalPoint",
-                "house": "Eighth_House",
-                "retrograde": False,
-            },
-            "first_house": {
-                "name": "First_House",
-                "quality": "Cardinal",
-                "element": "Earth",
-                "sign": "Cap",
-                "sign_num": 9,
-                "position": 0.0,
-                "abs_pos": 270.0,
-                "emoji": "♑️",
-                "point_type": "House",
-            },
-            "second_house": {
-                "name": "Second_House",
-                "quality": "Fixed",
-                "element": "Air",
-                "sign": "Aqu",
-                "sign_num": 10,
-                "position": 0.0,
-                "abs_pos": 300.0,
-                "emoji": "♒️",
-                "point_type": "House",
-            },
-            "third_house": {
-                "name": "Third_House",
-                "quality": "Mutable",
-                "element": "Water",
-                "sign": "Pis",
-                "sign_num": 11,
-                "position": 0.0,
-                "abs_pos": 330.0,
-                "emoji": "♓️",
-                "point_type": "House",
-            },
-            "fourth_house": {
-                "name": "Fourth_House",
-                "quality": "Cardinal",
-                "element": "Fire",
-                "sign": "Ari",
-                "sign_num": 0,
-                "position": 0.0,
-                "abs_pos": 0.0,
-                "emoji": "♈️",
-                "point_type": "House",
-            },
-            "fifth_house": {
-                "name": "Fifth_House",
-                "quality": "Fixed",
-                "element": "Earth",
-                "sign": "Tau",
-                "sign_num": 1,
-                "position": 0.0,
-                "abs_pos": 30.0,
-                "emoji": "♉️",
-                "point_type": "House",
-            },
-            "sixth_house": {
-                "name": "Sixth_House",
-                "quality": "Mutable",
-                "element": "Air",
-                "sign": "Gem",
-                "sign_num": 2,
-                "position": 0.0,
-                "abs_pos": 60.0,
-                "emoji": "♊️",
-                "point_type": "House",
-            },
-            "seventh_house": {
-                "name": "Seventh_House",
-                "quality": "Cardinal",
-                "element": "Water",
-                "sign": "Can",
-                "sign_num": 3,
-                "position": 0.0,
-                "abs_pos": 90.0,
-                "emoji": "♋️",
-                "point_type": "House",
-            },
-            "eighth_house": {
-                "name": "Eighth_House",
-                "quality": "Fixed",
-                "element": "Fire",
-                "sign": "Leo",
-                "sign_num": 4,
-                "position": 0.0,
-                "abs_pos": 120.0,
-                "emoji": "♌️",
-                "point_type": "House",
-            },
-            "ninth_house": {
-                "name": "Ninth_House",
-                "quality": "Mutable",
-                "element": "Earth",
-                "sign": "Vir",
-                "sign_num": 5,
-                "position": 0.0,
-                "abs_pos": 150.0,
-                "emoji": "♍️",
-                "point_type": "House",
-            },
-            "tenth_house": {
-                "name": "Tenth_House",
-                "quality": "Cardinal",
-                "element": "Air",
-                "sign": "Lib",
-                "sign_num": 6,
-                "position": 0.0,
-                "abs_pos": 180.0,
-                "emoji": "♎️",
-                "point_type": "House",
-            },
-            "eleventh_house": {
-                "name": "Eleventh_House",
-                "quality": "Fixed",
-                "element": "Water",
-                "sign": "Sco",
-                "sign_num": 7,
-                "position": 0.0,
-                "abs_pos": 210.0,
-                "emoji": "♏️",
-                "point_type": "House",
-            },
-            "twelfth_house": {
-                "name": "Twelfth_House",
-                "quality": "Mutable",
-                "element": "Fire",
-                "sign": "Sag",
-                "sign_num": 8,
-                "position": 0.0,
-                "abs_pos": 240.0,
-                "emoji": "♐️",
-                "point_type": "House",
-            },
-            "mean_north_lunar_node": {
-                "name": "Mean_North_Lunar_Node",
-                "quality": "Mutable",
-                "element": "Air",
-                "sign": "Gem",
-                "sign_num": 2,
-                "position": 28.91146207678823,
-                "abs_pos": 88.91146207678823,
-                "emoji": "♊️",
-                "point_type": "AstrologicalPoint",
-                "house": "Sixth_House",
-                "retrograde": True,
-            },
-            "true_north_lunar_node": {
-                "name": "True_North_Lunar_Node",
-                "quality": "Mutable",
-                "element": "Air",
-                "sign": "Gem",
-                "sign_num": 2,
-                "position": 27.29795395939222,
-                "abs_pos": 87.29795395939222,
-                "emoji": "♊️",
-                "point_type": "AstrologicalPoint",
-                "house": "Sixth_House",
-                "retrograde": True,
-            },
-            "mean_south_lunar_node": {
-                "name": "Mean_South_Lunar_Node",
-                "quality": "Mutable",
-                "element": "Fire",
-                "sign": "Sag",
-                "sign_num": 8,
-                "position": 28.91146207678821,
-                "abs_pos": 268.9114620767882,
-                "emoji": "♐️",
-                "point_type": "AstrologicalPoint",
-                "house": "Twelfth_House",
-                "retrograde": True,
-            },
-            "true_south_lunar_node": {
-                "name": "True_South_Lunar_Node",
-                "quality": "Mutable",
-                "element": "Fire",
-                "sign": "Sag",
-                "sign_num": 8,
-                "position": 27.2979539593922,
-                "abs_pos": 267.2979539593922,
-                "emoji": "♐️",
-                "point_type": "AstrologicalPoint",
-                "house": "Twelfth_House",
-                "retrograde": True,
-            },
-            "lunar_phase": {
-                "degrees_between_s_m": 201.07547248727337,
-                "moon_phase": 16,
-                "moon_emoji": "🌖",
-                "moon_phase_name": "Waning Gibbous"
-            },
-        }
 
     def test_basic_input_data(self):
         assert self.subject.name == self.expected_output["name"]
@@ -764,13 +376,3 @@ class TestAstrologicalSubjectJyotish:
         assert self.subject.lunar_phase.model_dump()["moon_phase"] == self.expected_output["lunar_phase"]["moon_phase"]
         assert self.subject.lunar_phase.model_dump()["moon_emoji"] == self.expected_output["lunar_phase"]["moon_emoji"]
         assert self.subject.lunar_phase.model_dump()["moon_phase_name"] == self.expected_output["lunar_phase"]["moon_phase_name"]
-
-
-if __name__ == "__main__":
-    import pytest
-    import logging
-
-    # Set the log level to CRITICAL
-    logging.basicConfig(level=logging.CRITICAL)
-
-    pytest.main(["-vv", "--log-level=CRITICAL", "--log-cli-level=CRITICAL", __file__])
